@@ -1,3 +1,4 @@
+import ipaddress
 from datetime import datetime, timedelta
 
 
@@ -35,6 +36,21 @@ def path_matches(request_path, cookie_path):
     return False
 
 
+def domain_matches(string: str, domain_string: str) -> bool:
+    string = string.lower()
+    domain_string = domain_string.lower()
+    try:
+        ipaddress.ip_address(string)
+        is_host = False
+    except ValueError:
+        is_host = True
+    return string == domain_string or (
+        string.endswith(domain_string)
+        and string[-(len(domain_string) + 1)] == "."
+        and is_host
+    )
+
+
 class Cookie6265:
     def __init__(self, key, value, uri, attrs):
         self.key = key
@@ -45,7 +61,7 @@ class Cookie6265:
         self.domain = attrs.get("Domain", "")
 
         if self.domain:
-            if not path_matches(uri.get_domain(), self.domain):
+            if not domain_matches(uri.get_domain(), self.domain):
                 raise ValueError()
             else:
                 self.host_only_flag = False
@@ -74,10 +90,8 @@ class Cookie6265:
             self.path = path
         else:
             self.path = default_path(uri)
-        secure = attrs.get("Secure", False)
-        self.secure_only_flag = secure
-        httponly = attrs.get("HttpOnly", False)
-        self.http_only_flag = httponly
+        self.secure_only_flag = "Secure" in attrs
+        self.http_only_flag = "HttpOnly" in attrs
 
     def __str__(self):
         return f"{self.key}={self.value}"
@@ -98,14 +112,14 @@ class Uri3986:
         self.fragment = fragment
 
     def updated_relative_ref(self, value):
-        hostname = self.ip or ".".join(self.host)
-        port = f":{self.port}" if self.port else ""
-        userinfo = f"{self.userinfo}@" if self.userinfo else ""
-
         if value.startswith("//"):
-            return f"{self.scheme}:{value}"
+            value = f"{self.scheme}:{value}"
         else:
-            return f"{self.scheme}://{userinfo}{hostname}{port}{value}"
+            userinfo = f"{self.userinfo}@" if self.userinfo else ""
+            hostname = self.ip or ".".join(self.host)
+            port = f":{self.port}" if self.port else ""
+            value = f"{self.scheme}://{userinfo}{hostname}{port}{value}"
+        return value
 
     @property
     def path(self):
