@@ -2,7 +2,7 @@ from datetime import datetime, timedelta
 
 import pytest
 
-from rfcparser.core import SetCookieParser6265, UriParser3986
+from rfcparser.core import DateParser6265, SetCookieParser6265, UriParser3986
 from rfcparser.object_abstractions import Cookie6265, Uri3986, path_matches
 
 
@@ -104,12 +104,6 @@ class TestUri3986:
         ],
     )
     def test_update_relative_path(self, value, newvalue, expected):
-        try:
-            UriParser3986().uri_parser.parse(
-                "//test.com/path?name=test", start="relative_ref"
-            )
-        except Exception:
-            raise Exception("Invalid relative_ref value") from None
         new_value = value.updated_relative_ref(newvalue)
         assert new_value == expected
 
@@ -130,7 +124,53 @@ class TestSetCookie6265:
                     secure_only_flag=False,
                     http_only_flag=False,
                 ),
-            )
+            ),
+            (
+                (
+                    "GPS=1; Domain=youtube.com; Expires=Tue, "
+                    "07-Feb-2023 13:20:04 GMT; Path=/; Secure; HttpOnly"
+                ),
+                UriParser3986().parse("https://youtube.com"),
+                dict(
+                    key="GPS",
+                    value="1",
+                    persistent_flag=True,
+                    domain="youtube.com",
+                    host_only_flag=False,
+                    secure_only_flag=True,
+                    http_only_flag=True,
+                ),
+            ),
+            (
+                (
+                    "ASD=1; Expires=Tue, "
+                    "07-Feb-2023 13:20:04 GMT; Domain=youtube.com; "
+                    "Secure; HttpOnly; Path=/"
+                ),
+                UriParser3986().parse("https://youtube.com"),
+                dict(
+                    key="ASD",
+                    value="1",
+                    persistent_flag=True,
+                    domain="youtube.com",
+                    host_only_flag=False,
+                    secure_only_flag=True,
+                    http_only_flag=True,
+                ),
+            ),
+            (
+                ("test=test1; Domain=youtube.com; " "Secure; Path=/"),
+                UriParser3986().parse("https://youtube.com"),
+                dict(
+                    key="test",
+                    value="test1",
+                    persistent_flag=False,
+                    domain="youtube.com",
+                    host_only_flag=False,
+                    secure_only_flag=True,
+                    http_only_flag=False,
+                ),
+            ),
         ],
     )
     def test_cookie_parse(self, value, uri, expected):
@@ -144,6 +184,24 @@ class TestSetCookie6265:
         assert cookie.http_only_flag == expected["http_only_flag"]
 
 
+class TestDateParser6265:
+    @pytest.mark.parametrize(
+        "value, expected",
+        (
+            (
+                "Tue, 07-Feb-2023 13:20:04 GMT",
+                datetime(day=7, month=2, year=2023, hour=13, minute=20, second=4),
+            ),
+            (
+                "Tue, 25-Aug-2003 17:45:04 GMT",
+                datetime(day=25, month=8, year=2003, hour=17, minute=45, second=4),
+            ),
+        ),
+    )
+    def test_date_parser(self, value, expected):
+        assert DateParser6265().parse(value) == expected
+
+
 @pytest.mark.parametrize(
     "request_path, cookie_path, expected",
     [
